@@ -158,6 +158,8 @@ namespace getfem {
     GA_NODE_INTERPOLATE_HESS_TEST,
     GA_NODE_INTERPOLATE_DIVERG_TEST,
     GA_NODE_INTERPOLATE_X,
+    GA_NODE_INTERPOLATE_ELT_K,
+    GA_NODE_INTERPOLATE_ELT_B,
     GA_NODE_INTERPOLATE_NORMAL,
     GA_NODE_INTERPOLATE_DERIVATIVE,
     GA_NODE_ELEMENTARY,
