@@ -552,8 +552,11 @@ namespace getfem {
           pnode1->nbc1 != pnode2->nbc1)
         return false;
       break;
-    case GA_NODE_INTERPOLATE_X: case GA_NODE_SECONDARY_DOMAIN_X:
-    case GA_NODE_INTERPOLATE_NORMAL: case GA_NODE_SECONDARY_DOMAIN_NORMAL:
+    case GA_NODE_INTERPOLATE_X:
+    case GA_NODE_SECONDARY_DOMAIN_X:
+    case GA_NODE_INTERPOLATE_ELT_K: case GA_NODE_INTERPOLATE_ELT_B:
+    case GA_NODE_INTERPOLATE_NORMAL:
+    case GA_NODE_SECONDARY_DOMAIN_NORMAL:
       if (pnode1->interpolate_name.compare(pnode2->interpolate_name))
         return false;
       break;
@@ -787,6 +790,7 @@ namespace getfem {
     switch(pnode->node_type) {
     case GA_NODE_INTERPOLATE:
     case GA_NODE_INTERPOLATE_X:
+    case GA_NODE_INTERPOLATE_ELT_K: case GA_NODE_INTERPOLATE_ELT_B:
     case GA_NODE_INTERPOLATE_NORMAL:
     case GA_NODE_INTERPOLATE_VAL:
     case GA_NODE_INTERPOLATE_GRAD:
@@ -989,6 +993,12 @@ namespace getfem {
     case GA_NODE_INTERPOLATE_NORMAL: case GA_NODE_SECONDARY_DOMAIN_NORMAL:
       str << "Normal";
       break;
+    case GA_NODE_INTERPOLATE_ELT_K:
+      str << "element_K";
+      break;
+    case GA_NODE_INTERPOLATE_ELT_B:
+      str << "element_B";
+      break;
     case GA_NODE_INTERPOLATE_DERIVATIVE:
       str << (pnode->test_function_type == 1 ? "Test_" : "Test2_")
           << "Interpolate_derivative(" << pnode->interpolate_name_der << ","
@@ -1416,9 +1426,7 @@ namespace getfem {
                            pnode_old->parent,pnode->children[0]);
             GMM_ASSERT1(pnode_old->children.empty(), "Internal error");
             delete pnode_old;
-
           } else { // Macro with parameters
-
             if (gam.nb_params()+1 != pnode->children.size())
               ga_throw_error(pnode->expr, pnode->pos,
                              "Bad number of parameters in the use of macro '"
@@ -1433,6 +1441,7 @@ namespace getfem {
             else
               tree.root = pnode;
             ga_replace_macro_params(tree, pnode, pnode_old->children);
+            tree.clear_node_rec(pnode_old);
           }
         }
       }
